#### Get Started

This is just dummy text ... Your first steps should be to get started. You will need to do the following:

- Sample 6
- Sample 7
- Sample 8

If you run into any of these setup issues, you must solve them before you can continue on.

→

#### Build your widgets

In this step, you will build the widgets for your system. The widgets form the various components that blah blah blah this is dummy text power the nuclear capabilities of your energy transformer into deep space using wormhole technology and warp drive speeds.

In order to configure your widgets, you will need to follow these topics:

- Sample 9
- Sample 10
- Sample 11

→

#### Publish your app

After you've configured all the necessary components to build your space transformer, you need to publish your app. Of course this content is also just dummy text. Pay no particular attention to the content but rather the format and placement of the map.

To publish your app, see the following:

- Sample 12
- Sample 13
- Sample 14

{% comment %} Copyright 2021 DLR {% endcomment %}